@@ -13,7 +13,7 @@ package Printer::Thermal;
 # This is free software; you can redistribute it and/or modify it under
 # the same terms as the Perl 5 programming language system itself.
 #
-our $VERSION = '0.21'; # VERSION
+our $VERSION = '0.22'; # VERSION
 
 # Dependencies
 use 5.010;
@@ -765,39 +765,39 @@ Printer::Thermal - Interface for Thermal (and some dot-matrix and inkjet) Printe
 
 =head1 VERSION
 
-version 0.21
+version 0.22
 
 =head1 SYNOPSIS
 
    use Printer::Thermal;
  
    #For Network Printers $port is 9100 in most cases but might differ depending on how you have configured your printer
-   $printer = Printer::Thermal-E<gt>new(device_ip=E<gt>$printer_ip,device_port=E<gt>$port);
+   $printer = Printer::Thermal->new(device_ip=>$printer_ip,device_port=>$port);
  
-   #These commands won't actually send anything to the printer but it will store all the merged data including control codes to send to printer in $printer-E<gt>print_string variable.
-   $printer-E<gt>write("Blah Blah \nReceipt Details\nFooter");
-   $printer-E<gt>bold_on();
-   $printer-E<gt>write("Bold Text");
-   $printer-E<gt>bold_off();
-   $printer-E<gt>print(); ##Sends the above set of code to the printer. Clears the buffer text in module.
+   #These commands won't actually send anything to the printer but it will store all the merged data including control codes to send to printer in $printer->print_string variable.
+   $printer->write("Blah Blah \nReceipt Details\nFooter");
+   $printer->bold_on();
+   $printer->write("Bold Text");
+   $printer->bold_off();
+   $printer->print(); ##Sends the above set of code to the printer. Clears the buffer text in module.
  
    #For local printer connected on serial port, check syslog(Usually under /var/log/syslog) for what device file was created for your printer when you connect it to your system(For plug and play printers).
    my $path = '/dev/ttyACM0';
-   $printer = Printer::Thermal-E<gt>new(serial_device_path=$path);
-   $printer-E<gt>write("Blah Blah \nReceipt Details\nFooter");
-   $printer-E<gt>bold_on();
-   $printer-E<gt>write("Bold Text");
-   $printer-E<gt>bold_off();
-   $printer-E<gt>print();
+   $printer = Printer::Thermal->new(serial_device_path=$path);
+   $printer->write("Blah Blah \nReceipt Details\nFooter");
+   $printer->bold_on();
+   $printer->write("Bold Text");
+   $printer->bold_off();
+   $printer->print();
  
    #For local printer connected on usb port, check syslog(Usually under /var/log/syslog) for what device file was created for your printer when you connect it to your system(For plug and play printers).
    my $path = '/dev/usb/lp0';
-   $printer = Printer::Thermal-E<gt>new(usb_device_path=$path);
-   $printer-E<gt>write("Blah Blah \nReceipt Details\nFooter");
-   $printer-E<gt>bold_on();
-   $printer-E<gt>write("Bold Text");
-   $printer-E<gt>bold_off();
-   $printer-E<gt>print();
+   $printer = Printer::Thermal->new(usb_device_path=$path);
+   $printer->write("Blah Blah \nReceipt Details\nFooter");
+   $printer->bold_on();
+   $printer->write("Bold Text");
+   $printer->bold_off();
+   $printer->print();
 
 =head1 DESCRIPTION
 
@@ -829,7 +829,7 @@ When used as a local serial device you can set the baudrate of the printer too.
 
 This param may be specified when creating printer object to make sure it works properly.
 
-$printer = Printer::Thermal-E<gt>new(serial_device_path =E<gt> '/dev/ttyACM0', baudrate =E<gt> 9600);
+$printer = Printer::Thermal->new(serial_device_path => '/dev/ttyACM0', baudrate => 9600);
 
 =head2 read_char_time
 
@@ -867,13 +867,13 @@ This is the direct device handle to the printer, You must almost never use this.
 Unless you are hacking through the module. If you are using this you must send me
 a bug report on why you had to use this.
 
-You can access it with $printer-E<gt>printer
+You can access it with $printer->printer
 
 =head2 print_string
 
-This contains the string in the module buffer that will be sent to the printer when you call $printer-E<gt>print();
+This contains the string in the module buffer that will be sent to the printer when you call $printer->print();
 
-my $print_string = $printer-E<gt>print_string
+my $print_string = $printer->print_string
 
 =head2 font
 
@@ -899,24 +899,24 @@ set unset double width property
 
 =head2 print
 
-$printer-E<gt>print()
+$printer->print()
 Sends the accumulated commands to the printer. All commands below need to be followed by a print() to send the data from buffer to the printer. You may call more than one printer command and then call print to send them all to printer together.
 The following bunch of commands print a text to a printer, move down one line, and cut the receipt paper.
 
-    $printer-E<gt>write("hello Printer\n");
-    $printer-E<gt>linefeed();
-    $printer-E<gt>cutpaper();
-    $printer-E<gt>print(); # Sends the all the commands before this to the printer in one go. 
+    $printer->write("hello Printer\n");
+    $printer->linefeed();
+    $printer->cutpaper();
+    $printer->print(); # Sends the all the commands before this to the printer in one go. 
 
 =head2 write
 
-$printer-E<gt>write("some text\n")
+$printer->write("some text\n")
 Writes a bunch of text that you pass here to the module buffer. 
-Note that this will not be passed to the printer till you call $printer-E<gt>print()
+Note that this will not be passed to the printer till you call $printer->print()
 
 =head2 left_margin
 
-$printer-E<gt>left_margin($nl,$nh)
+$printer->left_margin($nl,$nh)
 Sets the left margin code to the printer. takes two single byte parameters, $nl and $nh.
 To determine the value of these two bytes, use the INT and MOD conventions. INT indicates the integer (or whole number) part of a number, while MOD indicates the
 remainder of a division operation.
@@ -984,7 +984,7 @@ Function Specifies the character size (magnification ratio in the vertical and h
 
 Set ESC specified font size
 
-    $printer-E<gt>font_size_esc($size);
+    $printer->font_size_esc($size);
 
 =head2 font_b
 
@@ -1016,12 +1016,12 @@ Sets barcode height
 
 =head2 print_barcode
 
-$printer-E<gt>print_barcode($type,$string)
+$printer->print_barcode($type,$string)
 Prints barcode
 
 =head2 print_text
 
-$printer-E<gt>print_text($msg,$chars_per_line);
+$printer->print_text($msg,$chars_per_line);
 Prints some text defined by msg. If chars_per_line is defined, inserts newlines after the given amount. Use normal '\n' line breaks for empty lines.
 
 =head2 print_bitmap
@@ -1060,7 +1060,7 @@ If the printer prints out garbled characters instead of proper text, try specify
 
 =back
 
-     $printer = Printer::Thermal-E<gt>new(serial_device_path => '/dev/ttyACM0', baudrate => 9600);
+     $printer = Printer::Thermal->new(serial_device_path => '/dev/ttyACM0', baudrate => 9600);
 
 =head1 USAGE
 
